@@ -33,7 +33,7 @@
 #include "gtkintl.h"
 
 
-struct _GtkRadioMenuItemPriv
+struct _GtkRadioMenuItemPrivate
 {
   GSList *group;
 };
@@ -44,7 +44,7 @@ enum {
 };
 
 
-static void gtk_radio_menu_item_destroy        (GtkObject             *object);
+static void gtk_radio_menu_item_destroy        (GtkWidget             *widget);
 static void gtk_radio_menu_item_activate       (GtkMenuItem           *menu_item);
 static void gtk_radio_menu_item_set_property   (GObject               *object,
 						guint                  prop_id,
@@ -116,7 +116,7 @@ void
 gtk_radio_menu_item_set_group (GtkRadioMenuItem *radio_menu_item,
 			       GSList           *group)
 {
-  GtkRadioMenuItemPriv *priv;
+  GtkRadioMenuItemPrivate *priv;
   GtkWidget *old_group_singleton = NULL;
   GtkWidget *new_group_singleton = NULL;
   
@@ -248,11 +248,11 @@ gtk_radio_menu_item_new_with_mnemonic (GSList *group,
 /**
  * gtk_radio_menu_item_new_from_widget:
  * @group: An existing #GtkRadioMenuItem
- * 
+ *
  * Creates a new #GtkRadioMenuItem adding it to the same group as @group.
- * 
- * Return value: The new #GtkRadioMenuItem
- * 
+ *
+ * Return value: (transfer none): The new #GtkRadioMenuItem
+ *
  * Since: 2.4
  **/
 GtkWidget *
@@ -280,8 +280,8 @@ gtk_radio_menu_item_new_from_widget (GtkRadioMenuItem *group)
  *
  * The new #GtkRadioMenuItem is added to the same group as @group.
  *
- * Return value: The new #GtkRadioMenuItem
- * 
+ * Return value: (transfer none): The new #GtkRadioMenuItem
+ *
  * Since: 2.4
  **/
 GtkWidget *
@@ -300,14 +300,14 @@ gtk_radio_menu_item_new_with_mnemonic_from_widget (GtkRadioMenuItem *group,
 
 /**
  * gtk_radio_menu_item_new_with_label_from_widget:
- * @group: an existing #GtkRadioMenuItem 
+ * @group: an existing #GtkRadioMenuItem
  * @label: the text for the label
  *
  * Creates a new GtkRadioMenuItem whose child is a simple GtkLabel.
  * The new #GtkRadioMenuItem is added to the same group as @group.
  *
- * Return value: The new #GtkRadioMenuItem
- * 
+ * Return value: (transfer none): The new #GtkRadioMenuItem
+ *
  * Since: 2.4
  **/
 GtkWidget *
@@ -324,6 +324,16 @@ gtk_radio_menu_item_new_with_label_from_widget (GtkRadioMenuItem *group,
   return gtk_radio_menu_item_new_with_label (list, label);
 }
 
+/**
+ * gtk_radio_menu_item_get_group:
+ * @radio_menu_item: a #GtkRadioMenuItem
+ *
+ * Returns the group to which the radio menu item belongs, as a #GList of
+ * #GtkRadioMenuItem. The list belongs to GTK+ and should not be freed.
+ *
+ * Returns: (element-type GtkRadioMenuItem) (transfer none): the group
+ *     of @radio_menu_item
+ */
 GSList*
 gtk_radio_menu_item_get_group (GtkRadioMenuItem *radio_menu_item)
 {
@@ -337,16 +347,20 @@ static void
 gtk_radio_menu_item_class_init (GtkRadioMenuItemClass *klass)
 {
   GObjectClass *gobject_class;  
-  GtkObjectClass *object_class;
+  GtkWidgetClass *widget_class;
   GtkMenuItemClass *menu_item_class;
 
   gobject_class = G_OBJECT_CLASS (klass);
-  object_class = GTK_OBJECT_CLASS (klass);
+  widget_class = GTK_WIDGET_CLASS (klass);
   menu_item_class = GTK_MENU_ITEM_CLASS (klass);
 
   gobject_class->set_property = gtk_radio_menu_item_set_property;
   gobject_class->get_property = gtk_radio_menu_item_get_property;
 
+  widget_class->destroy = gtk_radio_menu_item_destroy;
+
+  menu_item_class->activate = gtk_radio_menu_item_activate;
+
   /**
    * GtkRadioMenuItem:group:
    * 
@@ -362,10 +376,6 @@ gtk_radio_menu_item_class_init (GtkRadioMenuItemClass *klass)
 							GTK_TYPE_RADIO_MENU_ITEM,
 							GTK_PARAM_WRITABLE));
 
-  object_class->destroy = gtk_radio_menu_item_destroy;
-
-  menu_item_class->activate = gtk_radio_menu_item_activate;
-
   /**
    * GtkStyle::group-changed:
    * @style: the object which received the signal
@@ -380,24 +390,24 @@ gtk_radio_menu_item_class_init (GtkRadioMenuItemClass *klass)
    * Since: 2.4
    */
   group_changed_signal = g_signal_new (I_("group-changed"),
-				       G_OBJECT_CLASS_TYPE (object_class),
+				       G_OBJECT_CLASS_TYPE (gobject_class),
 				       G_SIGNAL_RUN_FIRST,
 				       G_STRUCT_OFFSET (GtkRadioMenuItemClass, group_changed),
 				       NULL, NULL,
 				       _gtk_marshal_VOID__VOID,
 				       G_TYPE_NONE, 0);
 
-  g_type_class_add_private (klass, sizeof (GtkRadioMenuItemPriv));
+  g_type_class_add_private (klass, sizeof (GtkRadioMenuItemPrivate));
 }
 
 static void
 gtk_radio_menu_item_init (GtkRadioMenuItem *radio_menu_item)
 {
-  GtkRadioMenuItemPriv *priv;
+  GtkRadioMenuItemPrivate *priv;
 
   radio_menu_item->priv = G_TYPE_INSTANCE_GET_PRIVATE (radio_menu_item,
                                                        GTK_TYPE_RADIO_MENU_ITEM,
-                                                       GtkRadioMenuItemPriv);
+                                                       GtkRadioMenuItemPrivate);
   priv = radio_menu_item->priv;
 
   priv->group = g_slist_prepend (NULL, radio_menu_item);
@@ -405,10 +415,10 @@ gtk_radio_menu_item_init (GtkRadioMenuItem *radio_menu_item)
 }
 
 static void
-gtk_radio_menu_item_destroy (GtkObject *object)
+gtk_radio_menu_item_destroy (GtkWidget *widget)
 {
-  GtkRadioMenuItem *radio_menu_item = GTK_RADIO_MENU_ITEM (object);
-  GtkRadioMenuItemPriv *priv = radio_menu_item->priv;
+  GtkRadioMenuItem *radio_menu_item = GTK_RADIO_MENU_ITEM (widget);
+  GtkRadioMenuItemPrivate *priv = radio_menu_item->priv;
   GtkWidget *old_group_singleton = NULL;
   GtkRadioMenuItem *tmp_menu_item;
   GSList *tmp_list;
@@ -438,14 +448,14 @@ gtk_radio_menu_item_destroy (GtkObject *object)
   if (was_in_group)
     g_signal_emit (radio_menu_item, group_changed_signal, 0);
 
-  GTK_OBJECT_CLASS (gtk_radio_menu_item_parent_class)->destroy (object);
+  GTK_WIDGET_CLASS (gtk_radio_menu_item_parent_class)->destroy (widget);
 }
 
 static void
 gtk_radio_menu_item_activate (GtkMenuItem *menu_item)
 {
   GtkRadioMenuItem *radio_menu_item = GTK_RADIO_MENU_ITEM (menu_item);
-  GtkRadioMenuItemPriv *priv = radio_menu_item->priv;
+  GtkRadioMenuItemPrivate *priv = radio_menu_item->priv;
   GtkCheckMenuItem *check_menu_item = GTK_CHECK_MENU_ITEM (menu_item);
   GtkCheckMenuItem *tmp_menu_item;
   GtkAction        *action;
